@@ -23,7 +23,5 @@ class DeliveranceSelect(object):
 
         return self.application(environ, start_response)
 
-def make_middleware(application, global_conf, urispace=None):
-    if urispace is None:
-        raise ValueError('urispace must be specified')
-    return DeliveranceSelect(application, urispace)
+def make_middleware(application, global_conf):
+    return DeliveranceSelect(application)
